%% Polarisation transfer by chirp pulses
%  Spidyan simulations on Gd(III)
%  Reference - doi.org/10.1016/j.jmr.2015.12.014
%
%  ciaran.rogers@manchester.ac.uk
% =========================================================================
close all
clear all

% Gd(III) spin system
system.sqn=7/2; % spin quantum number
system.interactions={1,0,'z','e',3.5}; % Zeeman term in LO frame
system.init_state='-z'; % initial state

%% Distribution of D-values
iD = 100;
D0 = .73; % center of distribution, GHz
Dfwhm = .83; % FWHM of distribution, GHz
D = D0 + linspace(0,1,iD)*Dfwhm; % range of D values, GHz
weights = gaussian(D,D0,Dfwhm); % associated weights

%%
% Defining pulses
chirp.tp=[100 100]; % length of the pulses in ns
chirp.type={'WURST' 'WURST'};
chirp.WURSTN=[5 5];
chirp.Q = [5 5]; % critical adiabaticity of pulse
chirp.frq={[3.4 3.6] [3 3.2]}; % sweep
chirp.detection = [1 1]; % detect during pulse
chirp.t_rise = [10 10]; % rise time in ns

% Defining transition selective detection operators
options.det_op={'-z1,2','-z2,3','-z3,4','-z4,5','-z5,6','-z6,7','-z7,8'}; % transition selective detection operators
options.LO=30.43; % freq. of the local oscillator - difference between lab frame and LO frame defined in interactions
options.plot_domain = 'both';
options.labframe=0; % tells SPIDYAN whether to simulate in lab frame or not
options.awg.s_rate = 1.6;

signal = struct('sf',{0});

% Powder averaging 
[phi,theta,weights2] = sphgrid('Ci',20);
phi = phi*180/pi;
theta = theta*180/pi;

tic
% Looping over D-strain and powder orientations
for i = 1:length(D)
    system.D = D(i);
    system.E = D(i).*0.19;
    for iA = 1:200
        N = ceil(rand*length(theta));
        system.theta=theta(N);
        system.phi=phi(N);
        
        %% Input and propogation
        [experiment,options] = triple(chirp,options); % processing of pulse
        [system,state,options]=setup(system,options); % processing of system
        [state,signalX,experiment,options,tables]=homerun(state,system,experiment,options,[]); % propogation
        
        signal.sf = weights(i).*signalX.sf;
        %signal.sf = signal.sf(:,:) + weights(i).*signalX.sf;
        %signal.sf = weights2(i).*signal.sf;
    end
end
toc 

save(strcat('Polarisation_two_pulse_',num2str(iA),'_powder_average_',num2str(D0),'_D',num2str(Dfwhm),'_Dstrain.mat'))

%% Plotting population transfer
h=figure(1);
clf;
hold on;

plot(D,weights)
axis tight
xlabel('D (GHz)')
ylabel('Weights')

h=make_plot_nice_polar_gauss(h);
h.Renderer='opengl';

h=figure(2);
clf;
hold on;

plot(signalX.t(1:5:end),real(signalX.sf(:,(1:5:end))))
legend('-5/2 \leftrightarrow -7/2','-3/2 \leftrightarrow -5/2','-1/2 \leftrightarrow -3/2','+1/2 \leftrightarrow -1/2','+3/2 \leftrightarrow +1/2','+5/2 \leftrightarrow +3/2','+7/2 \leftrightarrow +5/2','Location','SouthWest')
xlabel('t (ns)')
ylabel('P/P_{0}')
title('Polarisation on detected transitions')
xlim([0 sum(chirp.tp)])
ylim([-1.25 4])

txt1 = ['FWHM of {\itD} distribution  = ' num2str(Dfwhm) ' GHz'];
% txt1 = ['Q = ' num2str(chirp.Q(1))];
txt = ['{\itD}  = ' num2str(D0) ' GHz'];
 
% formatSpec = '%.2f';
% txt1 = ['{\itE} = ' num2str(system.E(1),formatSpec) ' GHz']; 
text(5,1.3,txt,'FontSize',20)
text(80,-1,txt1,'FontSize',20)

h=make_plot_nice_polar(h);
h.Renderer='opengl';